# eric7.HelpViewer.HelpBookmarksWidget

Module implementing a widget showing the list of bookmarks.

### Global Attributes

None

### Classes

HelpBookmarksWidget | Class implementing a widget showing the list of bookmarks.

### Functions

None

## HelpBookmarksWidget

Class implementing a widget showing the list of bookmarks.

### Signals

escapePressed()
  emitted when the ESC key was pressed
newBackgroundTab(QUrl, str)
  emitted to open an entry in a new background tab
newTab(QUrl, str)
  emitted to open an entry in a new tab
openUrl(QUrl, str)
  emitted to open an entry in the current tab

### Derived from

QListWidget

### Class Attributes

UrlRole

### Class Methods

None

### Methods

HelpBookmarksWidget | Constructor
__addBookmark | Private slot to add a bookmark entry.
__bookmarkActivated | Private slot handling the activation of a bookmark.
__bookmarkCurrentPage | Private slot to bookmark the current page.
__deleteBookmarks | Private method to delete the given bookmark items.
__editBookmark | Private slot to edit a bookmark.
__exportBookmarks | Private slot to export the bookmarks into a JSON file.
__importBookmarks | Private slot to import bookmarks from a JSON file.
__loadBookmarks | Private method to load the defined bookmarks.
__newBookmark | Private slot to create a new bookmark.
__openBookmarks | Private method to open all or selected bookmarks.
__saveBookmarks | Private method to save the defined bookmarks.
__showBackgroundMenu | Private slot to show the background menu (i.e.
__showBookmarkContextMenu | Private slot to show the context menu for a bookmark.
__showBookmarksContextMenu | Private slot to show the context menu for multiple bookmark.
__showContextMenu | Private slot to handle the customContextMenuRequested signal of the viewlist.
addBookmark | Public slot to add a bookmark with given data.
keyPressEvent | Protected method handling key press events.

### Static Methods

None

#### HelpBookmarksWidget (Constructor)

HelpBookmarksWidget(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### HelpBookmarksWidget.__addBookmark

__addBookmark(title, url)

Private slot to add a bookmark entry.

title (str)
  title for the bookmark
url (str)
  URL for the bookmark

#### HelpBookmarksWidget.__bookmarkActivated

__bookmarkActivated(itm)

Private slot handling the activation of a bookmark.

itm (QListWidgetItem)
  reference to the activated item

#### HelpBookmarksWidget.__bookmarkCurrentPage

__bookmarkCurrentPage()

Private slot to bookmark the current page.

#### HelpBookmarksWidget.__deleteBookmarks

__deleteBookmarks(items)

Private method to delete the given bookmark items.

items (list of QListWidgetItem)
  list of bookmarks to be deleted

#### HelpBookmarksWidget.__editBookmark

__editBookmark(itm)

Private slot to edit a bookmark.

itm (QListWidgetItem)
  reference to the bookmark item to be edited

#### HelpBookmarksWidget.__exportBookmarks

__exportBookmarks(selected=False)

Private slot to export the bookmarks into a JSON file.

selected (bool (optional))
  flag indicating to export the selected bookmarks (defaults to False)

#### HelpBookmarksWidget.__importBookmarks

__importBookmarks()

Private slot to import bookmarks from a JSON file.

#### HelpBookmarksWidget.__loadBookmarks

__loadBookmarks()

Private method to load the defined bookmarks.

#### HelpBookmarksWidget.__newBookmark

__newBookmark()

Private slot to create a new bookmark.

#### HelpBookmarksWidget.__openBookmarks

__openBookmarks(selected=False)

Private method to open all or selected bookmarks.

selected (bool (optional))
  flag indicating to open the selected bookmarks (defaults to False)

#### HelpBookmarksWidget.__saveBookmarks

__saveBookmarks()

Private method to save the defined bookmarks.

#### HelpBookmarksWidget.__showBackgroundMenu

__showBackgroundMenu(point)

Private slot to show the background menu (i.e. no selection).

point (QPoint)
  position to open the menu at

#### HelpBookmarksWidget.__showBookmarkContextMenu

__showBookmarkContextMenu(point)

Private slot to show the context menu for a bookmark.

point (QPoint)
  position to open the menu at

#### HelpBookmarksWidget.__showBookmarksContextMenu

__showBookmarksContextMenu(point)

Private slot to show the context menu for multiple bookmark.

point (QPoint)
  position to open the menu at

#### HelpBookmarksWidget.__showContextMenu

__showContextMenu(point)

Private slot to handle the customContextMenuRequested signal of the viewlist.

point (QPoint)
  position to open the menu at

#### HelpBookmarksWidget.addBookmark

addBookmark(title, url)

Public slot to add a bookmark with given data.

title (str)
  title for the bookmark
url (QUrl)
  URL for the bookmark

#### HelpBookmarksWidget.keyPressEvent

keyPressEvent(evt)

Protected method handling key press events.

evt (QKeyEvent)
  reference to the key press event

Up